import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_apigatewayv2._jsii
import aws_cdk.aws_cognito._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/aws-apigatewayv2-authorizers",
    "1.105.0",
    __name__[0:-6],
    "aws-apigatewayv2-authorizers@1.105.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
